@@ -1,5 +1,5 @@
 """
- Copyright (C) 2019-2021 Intel Corporation
+ Copyright (C) 2019-2025 Intel Corporation
 
  SPDX-License-Identifier: MIT
 
@@ -107,6 +107,23 @@ def _mako_loader_cpp(path, namespace, tags, version, specs, meta):
     filename = "%s.h"%(name)
     fout = os.path.join(path, filename)
 
+    print("Generating %s..."%fout)
+    loc += util.makoWrite(
+        fin, fout,
+        name=name,
+        ver=version,
+        namespace=namespace,
+        tags=tags,
+        specs=specs,
+        meta=meta)
+
+    template = "ze_loader_internal.h.mako"
+    fin = os.path.join(templates_dir, template)
+
+    name = "%s_loader_internal_tmp"%(namespace)
+    filename = "%s.h"%(name)
+    fout = os.path.join(path, filename)
+
     print("Generating %s..."%fout)
     loc += util.makoWrite(
         fin, fout,
@@ -124,6 +141,23 @@ def _mako_loader_cpp(path, namespace, tags, version, specs, meta):
     filename = "%s.cpp"%(name)
     fout = os.path.join(path, filename)
 
+    print("Generating %s..."%fout)
+    loc += util.makoWrite(
+        fin, fout,
+        name=name,
+        ver=version,
+        namespace=namespace,
+        tags=tags,
+        specs=specs,
+        meta=meta)
+
+    template = "ldrddi_driver_ddi.cpp.mako"
+    fin = os.path.join(templates_dir, template)
+
+    name = "%s_ldrddi_driver_ddi"%(namespace)
+    filename = "%s.cpp"%(name)
+    fout = os.path.join(path, filename)
+
     print("Generating %s..."%fout)
     loc += util.makoWrite(
         fin, fout,
@@ -146,7 +180,8 @@ validation_files = {
     'param.cpp.mako' : ('checkers/parameter_validation', 'parameter_validation.cpp'),
     'param.h.mako' : ('checkers/parameter_validation', 'parameter_validation.h'),
     'handle_lifetime.h.mako' : ('handle_lifetime_tracking', 'handle_lifetime.h'),
-    'handle_lifetime.cpp.mako' : ('handle_lifetime_tracking', 'handle_lifetime.cpp')
+    'handle_lifetime.cpp.mako' : ('handle_lifetime_tracking', 'handle_lifetime.cpp'),
+    'certification.h.mako' : ('checkers/certification/generated', 'certification.h'),
 }
 
 def _mako_validation_layer_cpp(path, namespace, tags, version, specs, meta):
