@@ -1,5 +1,5 @@
 """
- Copyright (C) 2019-2021 Intel Corporation
+ Copyright (C) 2019-2025 Intel Corporation
 
  SPDX-License-Identifier: MIT
 
@@ -1726,6 +1726,23 @@ def get_class_function_objs_exp(specs, cname):
     return objects, exp_objects, optional
 
 
+"""
+Public:
+    returns the version of a function object
+"""
+def get_version(obj):
+    if obj_traits.is_function(obj):
+        ret_version = "ZE_API_VERSION_FORCE_UINT32"
+        version = obj.get('version')
+        if version is not None and version.startswith("1."):
+            try:
+                major, minor = version.split(".")
+                ret_version = f"ZE_API_VERSION_{major}_{minor}"
+            except Exception:
+                pass
+        assert(ret_version != "ZE_API_VERSION_FORCE_UINT32")
+        return ret_version
+
 """
 Public:
     returns string name of DDI table for function object
