@@ -10,13 +10,13 @@
 
 namespace ze_lib
 {
-
+#ifndef L0_STATIC_LOADER_BUILD
     void __attribute__((constructor)) createLibContext() {
         context = new context_t;
-    } 
-
-    void __attribute__((destructor)) deleteLibContext() {
-        delete context;
-    } 
+    }
+void __attribute__((destructor)) deleteLibContext() {
+    delete context;
+} 
+#endif
 
 }
\ No newline at end of file
