@@ -7,22 +7,13 @@
  */
 
 #include "../ze_lib.h"
-#ifndef DYNAMIC_LOAD_LOADER
+#ifndef L0_STATIC_LOADER_BUILD
 #include "../loader/ze_loader_internal.h"
 #endif
 
 namespace ze_lib
 {
-#ifdef DYNAMIC_LOAD_LOADER
-    export "C" BOOL APIENTRY DllMain(HINSTANCE hinstDLL, DWORD fdwReason, LPVOID lpvReserved) {
-        if (fdwReason == DLL_PROCESS_DETACH) {
-            delete context;
-        } else if (fdwReason == DLL_PROCESS_ATTACH) {
-            context = new context_t;
-        }
-        return TRUE;
-    }       
-#else
+#ifndef L0_STATIC_LOADER_BUILD
     extern "C" BOOL APIENTRY DllMain(HINSTANCE hinstDLL, DWORD fdwReason, LPVOID lpvReserved) {
         if (fdwReason == DLL_PROCESS_DETACH) {
             delete context;
