@@ -77,29 +77,10 @@ namespace loader
         permissiveDesc.stype = ZE_STRUCTURE_TYPE_INIT_DRIVER_TYPE_DESC;
         permissiveDesc.pNext = nullptr;
         permissiveDesc.flags = UINT32_MAX;
+        if (sysmanOnly) {
+            return true; // Sorting not fully supported by the spec due to missing zesDriverGetProperties for sysman drivers.
+        }
         for (auto &driver : *drivers) {
-            if (sysmanOnly) {
-                for (auto &coreDriver : this->zeDrivers) {
-                    if (coreDriver.name == driver.name) {
-                        if (!driver.dditable.ze.Global.pfnInitDrivers) {
-                            driver.dditable.ze.Global.pfnInitDrivers = coreDriver.dditable.ze.Global.pfnInitDrivers;
-                        }
-                        if (!driver.dditable.ze.Driver.pfnGet) {
-                            driver.dditable.ze.Driver.pfnGet = coreDriver.dditable.ze.Driver.pfnGet;
-                        }
-                        if (!driver.dditable.ze.Driver.pfnGetProperties) {
-                            driver.dditable.ze.Driver.pfnGetProperties = coreDriver.dditable.ze.Driver.pfnGetProperties;
-                        }
-                        if (!driver.dditable.ze.Device.pfnGet) {
-                            driver.dditable.ze.Device.pfnGet = coreDriver.dditable.ze.Device.pfnGet;
-                        }
-                        if (!driver.dditable.ze.Device.pfnGetProperties) {
-                            driver.dditable.ze.Device.pfnGetProperties = coreDriver.dditable.ze.Device.pfnGetProperties;
-                        }
-                        break;
-                    }
-                }
-            }
             uint32_t pCount = 0;
             std::vector<ze_driver_handle_t> driverHandles;
             ze_result_t res = ZE_RESULT_SUCCESS;
@@ -478,7 +459,18 @@ namespace loader
         loader::loaderZetDdiTable = new zet_dditable_t();
         loader::loaderZesDdiTable = new zes_dditable_t();
         debugTraceEnabled = getenv_tobool( "ZE_ENABLE_LOADER_DEBUG_TRACE" );
-        driverDDIPathDefault = getenv_tobool( "ZE_ENABLE_LOADER_DRIVER_DDI_PATH" );
+        // DDI Driver Extension Path is enabled by default.
+        // This can be overridden by the environment variable ZE_ENABLE_LOADER_DRIVER_DDI_PATH.
+        std::string ddiPathConfig = getenv_string("ZE_ENABLE_LOADER_DRIVER_DDI_PATH");
+        if (ddiPathConfig.empty()) {
+            driverDDIPathDefault = true;
+        } else if (strcmp(ddiPathConfig.c_str(), "1") == 0 || strcmp(ddiPathConfig.c_str(), "true") == 0) {
+            driverDDIPathDefault = true;
+        } else if (strcmp(ddiPathConfig.c_str(), "0") == 0 || strcmp(ddiPathConfig.c_str(), "false") == 0) {
+            driverDDIPathDefault = false;
+        } else {
+            driverDDIPathDefault = true; // fallback to the default for any other value
+        }
         auto discoveredDrivers = discoverEnabledDrivers();
         std::string loadLibraryErrorValue;
 
@@ -506,6 +498,10 @@ namespace loader
         if (debugTraceEnabled)
             debug_trace_message("Using Loader Library Path: ", loaderLibraryPath);
 
+        if (debugTraceEnabled && driverDDIPathDefault) {
+            debug_trace_message("DDI Driver Extension Path is Enabled", "");
+        }
+
         // To allow for two different sets of drivers to be in use between sysman and core/tools, we use and store the drivers in two vectors.
         // alldrivers stores all the drivers for cleanup when the library exits.
         zeDrivers.reserve( discoveredDrivers.size() + getenv_tobool( "ZE_ENABLE_NULL_DRIVER" ) );
